==> openurp-edu-base-adminapp-0.0.23-sources.jar: org/openurp/edu/base/web/action/TimesettingAction.scala <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.base.web.action

import org.beangle.commons.collection.Order
import org.beangle.data.dao.OqlBuilder
import org.beangle.webmvc.api.annotation.action
import org.beangle.webmvc.entity.action.RestfulAction
import org.openurp.base.model.School
import org.openurp.code.edu.model.DayPart
import org.openurp.edu.base.model.{ CourseUnit, Holiday, Project, TimeSetting }

class HolidayAction extends RestfulAction[Holiday] {
  override protected def getQueryBuilder: OqlBuilder[Holiday] = {
    val builder: OqlBuilder[Holiday] = OqlBuilder.from(entityName, "holiday")
    populateConditions(builder)
    builder.orderBy(get(Order.OrderStr).orNull).limit(getPageLimit)
  }

  override protected def editSetting(entity: Holiday): Unit = {
    put("schools", entityDao.getAll(classOf[School]))
  }
}

class TimeSettingAction extends ProjectRestfulAction[TimeSetting] {

  override protected def editSetting(setting: TimeSetting): Unit = {
    val projects = entityDao.findBy(classOf[Project], "id", getInt("project"))
    put("campuses", projects.head.campuses)
  }

}

class CourseUnitAction extends RestfulAction[CourseUnit] {

  override protected def indexSetting(): Unit = {
    put("settings", entityDao.findBy(classOf[TimeSetting], "project.id", getInt("project")))
  }

  override protected def getQueryBuilder: OqlBuilder[CourseUnit] = {
    val builder: OqlBuilder[CourseUnit] = OqlBuilder.from(entityName, "courseUnit")
    builder.where("courseUnit.setting.project.id=:projectId", getInt("project").get)
    populateConditions(builder)
    builder.orderBy(get(Order.OrderStr).orNull).limit(getPageLimit)
  }

  override protected def editSetting(entity: CourseUnit): Unit = {
    val projects = entityDao.findBy(classOf[Project], "id", getInt("project"))
    put("settings", entityDao.findBy(classOf[TimeSetting], "project", projects))
    put("parts", entityDao.getAll(classOf[DayPart]))
  }

}

==> openurp-edu-base-adminapp-0.0.34-sources.jar: org/openurp/edu/base/web/action/TimesettingAction.scala <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.edu.base.web.action

import org.beangle.commons.collection.Order
import org.beangle.data.dao.OqlBuilder
import org.beangle.webmvc.api.annotation.action
import org.beangle.webmvc.entity.action.RestfulAction
import org.openurp.base.model.School
import org.openurp.code.edu.model.DayPart
import org.openurp.edu.base.model.{CourseUnit, Holiday, Project, TimeSetting}

class HolidayAction extends RestfulAction[Holiday] {
  override protected def getQueryBuilder: OqlBuilder[Holiday] = {
    val builder: OqlBuilder[Holiday] = OqlBuilder.from(entityName, "holiday")
    populateConditions(builder)
    builder.orderBy(get(Order.OrderStr).orNull).limit(getPageLimit)
  }

  override protected def editSetting(entity: Holiday): Unit = {
    put("schools", entityDao.getAll(classOf[School]))
  }
}

class TimeSettingAction extends ProjectRestfulAction[TimeSetting] {

  override protected def editSetting(setting: TimeSetting): Unit = {
    put("campuses", getProject.campuses)
  }

}

class CourseUnitAction extends ProjectRestfulAction[CourseUnit] {

  override protected def indexSetting(): Unit = {
    put("settings", entityDao.findBy(classOf[TimeSetting], "project", List(getProject)))
  }

  override protected def getQueryBuilder: OqlBuilder[CourseUnit] = {
    val builder: OqlBuilder[CourseUnit] = OqlBuilder.from(entityName, "courseUnit")
    builder.where("courseUnit.setting.project=:project", getProject)
    populateConditions(builder)
    builder.orderBy(get(Order.OrderStr).orNull).limit(getPageLimit)
  }

  override protected def editSetting(entity: CourseUnit): Unit = {
    put("settings", entityDao.findBy(classOf[TimeSetting], "project", List(getProject)))
    put("parts", entityDao.getAll(classOf[DayPart]))
  }

}
